==> illumination_0.1.20090910-1.tar.gz: illumination-0.1.20090910/src/Lum/OS/Base/Behaviour.cpp <==
/*
  This source is part of the Illumination library
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/OS/Base/Behaviour.h>

#include <Lum/Dialog.h>
#include <Lum/Tab.h>

namespace Lum {
  namespace OS {
    namespace Base {

      DefaultBehaviour::DefaultBehaviour()
      {
      }

      DefaultBehaviour::~DefaultBehaviour()
      {
      }

      OS::Behaviour::CustomMenuHandler* DefaultBehaviour::GetCustomMenuHandler(OS::Window* window) const
      {
        return NULL;
      }

      void DefaultBehaviour::ApplyMultiViewDlg(Dialog* dialog,
                                               const Def::MultiView& multiView) const
      {
        Tab                  *tab=Tab::Create(true,true);
        Lum::Model::SizeTRef value=multiView.GetValue();
        Def::Menu            *menu=NULL;

        if (multiView.GetPreMenu()!=NULL) {
          menu=new Def::Menu(*multiView.GetPreMenu());

          // TODO: Build View menu

          if (multiView.GetPostMenu()!=NULL) {
            menu->Append(multiView.GetPostMenu());
          }
        }

        if (value.Valid()) {
          tab->SetModel(value);
        }

        for (std::list<Def::MultiView::View>::const_iterator view=multiView.GetViews().begin();
             view!=multiView.GetViews().end();
             ++view) {
          tab->Add(view->GetDesc().GetLabel(),view->GetObject());
        }

        dialog->SetMain(tab);
        dialog->SetMenu(menu);
      }
    }
  }
}

==> illumination_0.1.20091009-1.tar.gz: illumination-0.1.20091009/src/Lum/OS/Base/Behaviour.cpp <==
/*
  This source is part of the Illumination library
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/OS/Base/Behaviour.h>

#include <Lum/Combo.h>
#include <Lum/Dialog.h>
#include <Lum/Tab.h>

namespace Lum {
  namespace OS {
    namespace Base {

      DefaultBehaviour::DefaultBehaviour()
      {
      }

      DefaultBehaviour::~DefaultBehaviour()
      {
      }

      OS::Behaviour::CustomMenuHandler* DefaultBehaviour::GetCustomMenuHandler(OS::Window* window) const
      {
        return NULL;
      }

      void DefaultBehaviour::ApplyMultiViewDlg(Dialog* dialog,
                                               const Def::MultiView& multiView) const
      {
        Tab                  *tab=Tab::Create(true,true);
        Lum::Model::SizeTRef value=multiView.GetValue();
        Def::Menu            *menu=NULL;

        if (multiView.GetPreMenu()!=NULL) {
          menu=new Def::Menu(*multiView.GetPreMenu());

          // TODO: Build View menu

          if (multiView.GetPostMenu()!=NULL) {
            menu->Append(multiView.GetPostMenu());
          }
        }

        if (value.Valid()) {
          tab->SetModel(value);
        }

        for (std::list<Def::MultiView::View>::const_iterator view=multiView.GetViews().begin();
             view!=multiView.GetViews().end();
             ++view) {
          tab->Add(view->GetDesc().GetLabel(),view->GetObject());
        }

        dialog->SetMain(tab);
        dialog->SetMenu(menu);
      }

      Lum::Object* DefaultBehaviour::GetOneOfManyControl(Def::OneOfMany& def) const
      {
        IndexCombo *control;

        control=new IndexCombo();
        control->SetFlex(true,false);
        control->SetModel(def.GetValue());
        control->SetTableModel(def.GetChoices());
        control->SetHeaderModel(def.GetChoicesHeader());

        return control;
      }

      Lum::Object* DefaultBehaviour::GetOneOfManyControl(Def::OneOfMany& def,
                                                         bool horizFlex,
                                                         bool vertFlex) const
      {
        Lum::Object* control;

        control=GetOneOfManyControl(def);

        if (control!=NULL) {
          control->SetFlex(horizFlex,vertFlex);
        }

        return control;
      }
    }
  }
}
